pub trait EventEmitter: Send + Sync {
// Required method
fn emit(&self, event: &str, payload: &str) -> Result<()>;
}Expand description
Trait for emitting events from core to external consumers.
Replaces Option<tauri::AppHandle> in MemoryDB and other modules that
previously needed to push updates to the Tauri frontend.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".